package com.ruoyi.model.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.model.mapper.FinalConfigMapper;
import com.ruoyi.model.domain.FinalConfig;
import com.ruoyi.model.service.IFinalConfigService;

/**
 * 最终准备页面配置Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
@Service
public class FinalConfigServiceImpl implements IFinalConfigService 
{
    @Autowired
    private FinalConfigMapper finalConfigMapper;

    /**
     * 查询最终准备页面配置
     * 
     * @param id 最终准备页面配置主键
     * @return 最终准备页面配置
     */
    @Override
    public FinalConfig selectFinalConfigById(Long id)
    {
        return finalConfigMapper.selectFinalConfigById(id);
    }

    /**
     * 查询最终准备页面配置列表
     * 
     * @param finalConfig 最终准备页面配置
     * @return 最终准备页面配置
     */
    @Override
    public List<FinalConfig> selectFinalConfigList(FinalConfig finalConfig)
    {
        return finalConfigMapper.selectFinalConfigList(finalConfig);
    }

    /**
     * 新增最终准备页面配置
     * 
     * @param finalConfig 最终准备页面配置
     * @return 结果
     */
    @Override
    public int insertFinalConfig(FinalConfig finalConfig)
    {
        return finalConfigMapper.insertFinalConfig(finalConfig);
    }

    /**
     * 修改最终准备页面配置
     * 
     * @param finalConfig 最终准备页面配置
     * @return 结果
     */
    @Override
    public int updateFinalConfig(FinalConfig finalConfig)
    {
        return finalConfigMapper.updateFinalConfig(finalConfig);
    }

    /**
     * 批量删除最终准备页面配置
     * 
     * @param ids 需要删除的最终准备页面配置主键
     * @return 结果
     */
    @Override
    public int deleteFinalConfigByIds(Long[] ids)
    {
        return finalConfigMapper.deleteFinalConfigByIds(ids);
    }

    /**
     * 删除最终准备页面配置信息
     * 
     * @param id 最终准备页面配置主键
     * @return 结果
     */
    @Override
    public int deleteFinalConfigById(Long id)
    {
        return finalConfigMapper.deleteFinalConfigById(id);
    }

    /**
     * 查询最终准备页面配置列表
     *
     * @return 最终准备页面配置集合
     */
    @Override
    public List<FinalConfig> getFinalConfigList() {
        return finalConfigMapper.getFinalConfigList();
    }
}
